# frida-start

Wrapper tool to identify the remote device and push device specific frida-server binary.

## Installing

```bash
pip install frida-start
```

## Running

```bash
$ frida-start -h

usage: frida-start [-h] [-d DEVICE_NAME] [--version]

optional arguments:
  -h, --help            show this help message and exit
  -d DEVICE_NAME, --device-name DEVICE_NAME
  -f, --force           force download
  --version             show program's version number and exit
```
